Contributing
============

Pull Requests
-------------
Submissions should be done via Pull Requests on the Stone Soup GitHub repo.
Currently we are using
`GitHub Flow <https://guides.github.com/introduction/flow/index.html>`_ as our
approach to development.

Code Style
----------
All code should follow PEP 8. Flake8 can be used to check for issues. If
necessary, in-line ignores can be added.

Documentation
-------------
In Stone Soup, NumPy Doc style documentation is used. It must be provided for
all public interfaces, and should also be provided for private interfaces.

Tests
-----
PyTest is used for testing in Stone Soup. Tests should be provide to test
functionality and also ensuring exceptions are raised or managed appropriately.

License
-------
Any contributions submitted are to be under the MIT or similar non-copyleft
license. MIT License will be assumed to be unless otherwise stated on the pull
request.
